Limit

Struct Limit 

pub struct Limit {
    pub max: Option<i32>,
    pub up_to_remaining_quota: Option<bool>,
    pub forbid_partial_delivery: Option<bool>,
}
Limit : Limit of the Narrowcast

Fields

max: Option<i32>

The maximum number of narrowcast messages to send. Use this parameter to limit the number of narrowcast messages sent. The recipients will be chosen at random.

up_to_remaining_quota: Option<bool>

If true, the message will be sent within the maximum number of deliverable messages. The default value is false. Targets will be selected at random.

forbid_partial_delivery: Option<bool>

This option prevents messages from being delivered to only a subset of the target audience. If true, the narrowcast request success but fails asynchronously. You can check whether message delivery was canceled by retrieving the narrowcast message progress. This property can be set to true only if upToRemainingQuota is set to true.

Implementations

Source

impl Limit

pub fn new() -> Limit

Limit of the Narrowcast